@@ -6,18 +6,18 @@ import (
 	"os"
 	"time"
 
-	"github.com/open-cluster-management/submariner-addon/pkg/cloud"
+	"github.com/stolostron/submariner-addon/pkg/cloud"
 	"k8s.io/client-go/dynamic"
 
 	"github.com/openshift/library-go/pkg/controller/controllercmd"
 	"github.com/spf13/cobra"
 
-	configclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
-	configinformers "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
-	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarineraddonagent"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarineragent"
-	"github.com/open-cluster-management/submariner-addon/pkg/hub/submarinerbroker"
+	configclient "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
+	configinformers "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/informers/externalversions"
+	"github.com/stolostron/submariner-addon/pkg/helpers"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarineraddonagent"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarineragent"
+	"github.com/stolostron/submariner-addon/pkg/hub/submarinerbroker"
 	apiextensionsclientset "k8s.io/apiextensions-apiserver/pkg/client/clientset/clientset"
 	apiextensionsinformers "k8s.io/apiextensions-apiserver/pkg/client/informers/externalversions"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
