@@ -8,11 +8,11 @@ import (
 	"os"
 	"strings"
 
-	configv1alpha1 "github.com/open-cluster-management/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
-	configclient "github.com/open-cluster-management/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
-	"github.com/open-cluster-management/submariner-addon/pkg/helpers"
 	apiconfigv1 "github.com/openshift/api/config/v1"
 	"github.com/openshift/library-go/pkg/operator/events"
+	configv1alpha1 "github.com/stolostron/submariner-addon/pkg/apis/submarinerconfig/v1alpha1"
+	configclient "github.com/stolostron/submariner-addon/pkg/client/submarinerconfig/clientset/versioned"
+	"github.com/stolostron/submariner-addon/pkg/helpers"
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
@@ -57,6 +57,7 @@ type SubmarinerBrokerInfo struct {
 	IPSecIKEPort              int
 	IPSecNATTPort             int
 	InstallationNamespace     string
+	InstallPlanApproval       string
 	BrokerAPIServer           string
 	BrokerNamespace           string
 	BrokerToken               string
@@ -96,6 +97,7 @@ func Get(
 		CatalogSource:          defaultCatalogSource,
 		CatalogSourceNamespace: defaultCatalogSourceNamespace,
 		InstallationNamespace:  defaultInstallationNamespace,
+		InstallPlanApproval:    "Automatic",
 	}
 
 	if len(installationNamespace) != 0 {
@@ -166,6 +168,10 @@ func applySubmarinerConfig(
 		brokerInfo.CatalogStartingCSV = submarinerConfig.Spec.SubscriptionConfig.StartingCSV
 	}
 
+	if submarinerConfig.Spec.SubscriptionConfig.InstallPlanApproval != "" {
+		brokerInfo.InstallPlanApproval = submarinerConfig.Spec.SubscriptionConfig.InstallPlanApproval
+	}
+
 	if submarinerConfig.Spec.ImagePullSpecs.SubmarinerImagePullSpec != "" {
 		brokerInfo.SubmarinerGatewayImage = submarinerConfig.Spec.ImagePullSpecs.SubmarinerImagePullSpec
 	}
